@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 from datetime import datetime, timedelta
 from enum import Enum
+import os
 from os import makedirs, PathLike
 from pathlib import Path
 from textwrap import indent
@@ -330,11 +331,13 @@ class ConfigurationFile(ABC):
 
         if filename.is_dir():
             filename = filename / self.name
-            LOGGER.warning(f'creating new file "{filename}"')
+            LOGGER.warning(
+                f'creating new file "{os.path.relpath(filename.resolve(), Path.cwd())}"'
+            )
 
         if filename.exists():
             LOGGER.warning(
-                f'{"overwriting" if overwrite else "skipping"} ' f'existing file "{filename}"'
+                f'{"overwriting" if overwrite else "skipping"} existing file "{os.path.relpath(filename.resolve(), Path.cwd())}"'
             )
         if not filename.exists() or overwrite:
             with open(filename, 'w', newline='\n') as output_file:
@@ -381,8 +384,6 @@ class MeshFile(ConfigurationFile):
 
 
 class ModelConfigurationFile(ConfigurationFile):
-    """ https://ufs-weather-model.readthedocs.io/en/ufs-v1.0.0/InputsOutputs.html#modelconfigparams """
-
     name = 'model_configure'
 
     def __init__(
@@ -409,7 +410,7 @@ class ModelConfigurationFile(ConfigurationFile):
         duration_hours = round(self.duration / timedelta(hours=1))
         return '\n'.join(
             [
-                f'total_member:            {len(self.sequence.models)}',
+                'total_member:            1',
                 'print_esmf:              .true.',
                 f'namelist:                {"atm_namelist.rc" if self.create_atm_namelist_rc else "model_configure"}',
                 f'PE_MEMBER01:             {self.sequence.processors}',
